BatchResponse class

Batch response containing multiple results

Constructors

BatchResponse({required List<Map<String, dynamic>> results, required List<String> errors, required Duration processingTime})

Properties

errorCount int
final
errors List<String>
final
hasErrors bool
no setter
hashCode int
The hash code for this object.
no setterinherited
processingTime Duration
final
results List<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successCount int
final
successRate double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited