DynamicPromptPlugin class

Dynamic prompt plugin generated by LLM

Inheritance

Constructors

DynamicPromptPlugin({required String name, required String description, required List<LlmPromptArgument> arguments, required String systemPrompt, required String userPromptTemplate})

Properties

description String
Plugin description
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
Plugin name
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt String
final
userPromptTemplate String
final
version String
Plugin version
finalinherited

Methods

execute(Map<String, dynamic> arguments) Future<LlmGetPromptResult>
Execute the prompt with the given arguments
inherited
getConfigValue<T>(String key, T defaultValue) → T
Get a configured value with fallback
inherited
getPromptDefinition() LlmPrompt
Get the prompt definition
inherited
initialize(Map<String, dynamic> config) Future<void>
Initialize the plugin with configuration
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onExecute(Map<String, dynamic> arguments) Future<LlmGetPromptResult>
Hook for plugin-specific execution logic
override
onInitialize(Map<String, dynamic> config) Future<void>
Hook for plugin-specific initialization logic
inherited
onShutdown() Future<void>
Hook for plugin-specific shutdown logic
inherited
shutdown() Future<void>
Shutdown and clean up resources
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited