DynamicResourcePlugin class

Dynamic resource plugin generated by LLM

Implemented types

Constructors

DynamicResourcePlugin({required String name, required String description, required String uri, required String content, required LlmServer llmServer, required String sessionId, String? mimeType, String? uriTemplate})

Properties

content String
final
description String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
llmServer LlmServer
final
mimeType String?
Resource MIME type
finalinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
uri String
Resource URI
finalinherited
uriTemplate String?
Resource URI template
finalinherited
version String
finalinherited

Methods

getConfigValue<T>(String key, T defaultValue) → T
Get a configured value with fallback
inherited
getResourceDefinition() LlmResource
Get the resource definition
inherited
initialize(Map<String, dynamic> config) Future<void>
Initialize the plugin with configuration
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onInitialize(Map<String, dynamic> config) Future<void>
Hook for plugin-specific initialization logic
inherited
onRead(Map<String, dynamic> parameters) Future<LlmReadResourceResult>
Hook for plugin-specific read logic
onShutdown() Future<void>
Hook for plugin-specific shutdown logic
inherited
read(Map<String, dynamic> parameters) Future<LlmReadResourceResult>
Read the resource with the given parameters
inherited
shutdown() Future<void>
Shutdown and clean up resources
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited