ErrorCircuitBreaker class

Circuit breaker for error handling

Constructors

ErrorCircuitBreaker({required String name, required int threshold, required Duration timeout})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
no setter
isHalfOpen bool
no setter
isOpen bool
no setter
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold int
final
timeout Duration
final

Methods

execute<T>(Future<T> operation()) Future<T>
getStatus() Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited