LlmEmbeddingPlugin class

Plugin for generating embeddings

Inheritance

Constructors

LlmEmbeddingPlugin({required LlmInterface llmProvider, PerformanceMonitor? performanceMonitor})

Properties

description String
Plugin description
finalinherited
hashCode int
The hash code for this object.
no setterinherited
llmProvider LlmInterface
final
name String
Plugin name
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
Plugin version
finalinherited

Methods

execute(Map<String, dynamic> arguments) Future<LlmCallToolResult>
Execute the tool with the given arguments
inherited
getConfigValue<T>(String key, T defaultValue) → T
Get a configured value with fallback
inherited
getToolDefinition() LlmTool
Get the tool definition
inherited
initialize(Map<String, dynamic> config) Future<void>
Initialize the plugin with configuration
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onExecute(Map<String, dynamic> args) Future<LlmCallToolResult>
Hook for plugin-specific execution logic
override
onInitialize(Map<String, dynamic> config) Future<void>
Hook for plugin-specific initialization logic
inherited
onShutdown() Future<void>
Hook for plugin-specific shutdown logic
inherited
shutdown() Future<void>
Shutdown and clean up resources
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited