LlmTask<T> class

Represents a scheduled task with priority

Constructors

LlmTask({required String id, required Future<T> task(), int priority = 0, DateTime? createdAt, required String category, Map<String, dynamic> metadata = const {}})

Properties

category String
Task category for monitoring
final
completer Completer<T>
Completer to resolve when task completes
final
createdAt DateTime
When the task was created
final
future Future<T>
Future that completes when the task is done
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Unique task ID
final
metadata Map<String, dynamic>
Optional metadata
final
priority int
Priority level (higher numbers = higher priority)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task Future<T> Function()
Task function to execute
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited