LlmToolCall class

Tool call request

Constructors

LlmToolCall({required String name, required Map<String, dynamic> arguments, String? id})

Properties

arguments Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOrCreateId() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
withId(String newId) LlmToolCall

Operators

operator ==(Object other) bool
The equality operator.
inherited