ParallelExecutor class

Class that manages parallel operations for multiple LLMs

Constructors

ParallelExecutor({required List<LlmInterface> providers, ResultAggregator? aggregator})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeParallel(LlmRequest request) Future<LlmResponse>
Execute requests in parallel to multiple LLM providers
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited