ProviderOptions class

Configuration options for LLM providers

Constructors

ProviderOptions({Duration timeout = const Duration(seconds: 30), bool retryOnFailure = true, int maxRetries = 3, Duration retryDelay = const Duration(seconds: 1), String? defaultModel, Map<String, dynamic> additionalOptions = const {}})
Create provider options

Properties

additionalOptions Map<String, dynamic>
Additional provider-specific options
final
defaultModel String?
Default model to use
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int
Maximum number of retries
final
retryDelay Duration
Retry delay
final
retryOnFailure bool
Whether to retry failed requests
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
Timeout for requests
final

Methods

copyWith({Duration? timeout, bool? retryOnFailure, int? maxRetries, Duration? retryDelay, String? defaultModel, Map<String, dynamic>? additionalOptions}) ProviderOptions
Create a copy with modified values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited