StorageManager class abstract

Abstract interface for storage management

Implementers

Constructors

StorageManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all storage
delete(String key) Future<bool>
Delete an item from storage
exists(String key) Future<bool>
Check if a key exists in storage
listKeys([String? prefix]) Future<List<String>>
List all keys in storage
loadData(String key) Future<List<int>?>
Load binary data from storage
loadObject(String key) Future<Map<String, dynamic>?>
Load an object from storage
loadString(String key) Future<String?>
Load a string from storage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveData(String key, List<int> data) Future<void>
Save a binary data to storage
saveObject(String key, Map<String, dynamic> object) Future<void>
Save an object to storage (serialized as JSON)
saveString(String key, String value) Future<void>
Save a raw string to storage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited