VectorStoreConfig class

Configuration options for vector stores

Constructors

VectorStoreConfig({String? apiKey, String? baseUrl, String? environment, String? defaultNamespace, int dimension = 1536, Map<String, dynamic> options = const {}})

Properties

apiKey String?
API key for the vector store service
final
baseUrl String?
Base URL for the vector store service (if applicable)
final
defaultNamespace String?
Default namespace/collection name
final
dimension int
Vector dimension
final
environment String?
Environment (e.g., production, staging)
final
hashCode int
The hash code for this object.
no setterinherited
options Map<String, dynamic>
Additional provider-specific options
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? apiKey, String? baseUrl, String? environment, String? defaultNamespace, int? dimension, Map<String, dynamic>? options}) VectorStoreConfig
Create a copy with modified values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited