BasePromptPlugin class abstract
Base implementation of a prompt plugin
- Implemented types
- Implementers
Constructors
-
BasePromptPlugin({required String name, required String version, required String description, required List<
LlmPromptArgument> arguments})
Properties
- description → String
-
Plugin description
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Plugin name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
Plugin version
final
Methods
-
execute(
Map< String, dynamic> arguments) → Future<LlmGetPromptResult> -
Execute the prompt with the given arguments
override
-
getConfigValue<
T> (String key, T defaultValue) → T - Get a configured value with fallback
-
getPromptDefinition(
) → LlmPrompt -
Get the prompt definition
override
-
initialize(
Map< String, dynamic> config) → Future<void> -
Initialize the plugin with configuration
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onExecute(
Map< String, dynamic> arguments) → Future<LlmGetPromptResult> - Hook for plugin-specific execution logic
-
onInitialize(
Map< String, dynamic> config) → Future<void> - Hook for plugin-specific initialization logic
-
onShutdown(
) → Future< void> - Hook for plugin-specific shutdown logic
-
shutdown(
) → Future< void> -
Shutdown and clean up resources
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited