ErrorCircuitBreaker class
Circuit breaker for error handling
Constructors
- ErrorCircuitBreaker({required String name, required int threshold, required Duration timeout})
Properties
Methods
-
execute<
T> (Future< T> operation()) → Future<T> -
getStatus(
) → Map< String, dynamic> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited