LifecycleRequest class
Lifecycle operation request
Constructors
-
LifecycleRequest({required String requestId, required String serverId, required String operation, Map<
String, dynamic> parameters = const {}, required LifecycleTransitionReason reason, required DateTime timestamp}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- operation → String
-
final
-
parameters
→ Map<
String, dynamic> -
final
- reason → LifecycleTransitionReason
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverId → String
-
final
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited