PromptPlugin class abstract
Interface for prompt plugins that provide prompt templates
- Inheritance
- Implementers
Constructors
Properties
- description → String
-
Plugin description
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Plugin name
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
Plugin version
no setterinherited
Methods
-
execute(
Map< String, dynamic> arguments) → Future<LlmGetPromptResult> - Execute the prompt with the given arguments
-
getPromptDefinition(
) → LlmPrompt - Get the prompt definition
-
initialize(
Map< String, dynamic> config) → Future<void> -
Initialize the plugin with configuration
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shutdown(
) → Future< void> -
Shutdown and clean up resources
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited