ValidationError class
Validation errors (invalid inputs)
- Inheritance
-
- Object
- Error
- McpLlmError
- ValidationError
Constructors
- ValidationError(String message, {String? field, dynamic originalError, StackTrace? stackTrace})
Properties
- field → String?
-
Field that failed validation, if applicable
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error message
finalinherited
- originalError → dynamic
-
Original error, if any
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace, if available
finalinherited
- type → ErrorType
-
Error type
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited